@@ -1,12 +1,16 @@
+"""Entrypoint for clidb, constructs the app and run its"""
+
 import argparse
 import os
-from logging import getLogger
+import platform
+from typing import Any, List, Optional
 
 from rich.text import Text
 from textual.app import App
 from textual.views import DockView
 from textual.widgets import FileClick, ScrollView
 
+from clidb import __version__
 from clidb.database import DatabaseController
 from clidb.events import (
     DatabaseViewsUpdate,
@@ -18,37 +22,72 @@ from clidb.events import (
 )
 from clidb.views import DatabaseView, DataFileTree, QueryInput, ResultsView
 
-logger = getLogger()
+
+def run(argv: Optional[List[str]] = None) -> None:
+    """Entrypoint for clidb, parses arguments and initiates the app"""
+    parser = argparse.ArgumentParser(description="cli sql client for local data files.")
+    parser.add_argument(
+        "path", nargs="?", default=os.getcwd(), help="path to display", type=str
+    )
+    parser.add_argument(
+        "--clipboard",
+        action="store_true",
+        help="Display clipboard contents as view.",
+    )
+    parser.add_argument(
+        "--row-lines", action="store_true", help="Render row separator lines."
+    )
+
+    parser.add_argument(
+        "--version",
+        "-v",
+        action="version",
+        version=_get_version(),
+        help="Display version information.",
+    )
+
+    parser.add_argument(
+        "--log",
+        "-l",
+        type=str,
+        default=None,
+        help="Log file for debug messages.",
+    )
+
+    args = parser.parse_args(argv)
+    CliDB.run(**vars(args))
 
 
 class CliDB(App):
     """CLI interface for a local db sql client"""
 
+    def __init__(self, **kwargs: Any) -> None:
+        """
+        log: log file to write debug messages to
+        clipboard: flag to enable creating a view of clipboard contents
+        row_lines: flag to print lines between rows
+        """
+        self.config = {}
+        for config_option in ["clipboard", "row_lines", "path"]:
+            self.config[config_option] = kwargs.get(config_option, False)
+
+        super().__init__(title="clidb", **kwargs)
+
+        # Components to be initialised on load / mount
+        self.database: DatabaseController
+        self.query_view: QueryInput
+        self.results_view: ResultsView
+        self.database_view: DatabaseView
+        self.directory_view: DataFileTree
+        self.sidebar: DockView
+
     async def on_load(self) -> None:
         """Sent before going in to application mode."""
         await self.bind("q", "quit", "Quit")
         await self.bind("enter", "query", "Query")
 
-        parser = argparse.ArgumentParser(
-            description="cli sql client for local data files."
-        )
-        parser.add_argument(
-            "path", nargs="?", default=os.getcwd(), help="path to display", type=str
-        )
-        parser.add_argument(
-            "--clipboard",
-            action="store_true",
-            help="Display clipboard contents as view.",
-        )
-        parser.add_argument(
-            "--row-lines", action="store_true", help="Render row separator lines."
-        )
-        args = parser.parse_args()
-
-        self.path = args.path
-
         self.database = DatabaseController(
-            load_clipboard=args.clipboard, row_lines=args.row_lines
+            load_clipboard=self.config["clipboard"], row_lines=self.config["row_lines"]
         )
         self.register(self.database, self)
 
@@ -64,11 +103,12 @@ class CliDB(App):
         self.results_view = ResultsView(auto_width=True, name="ResultsView")
         self.database_view = DatabaseView("Views", name="DatabaseView")
 
-        if os.path.isdir(self.path) or self.path.startswith("s3://"):
-            view_dir = self.path
+        path = self.config["path"]
+        if os.path.isdir(path) or path.startswith("s3://"):
+            view_dir = path
         else:
-            view_dir = os.path.dirname(self.path) or os.getcwd()
-            await self.database.post_message(OpenFile(self, self.path))
+            view_dir = os.path.dirname(path) or os.getcwd()
+            await self.database.post_message(OpenFile(self, path))
 
         self.directory_view = DataFileTree(str(view_dir), "DirTree")
         self.sidebar = DockView(name="Sidebar")
@@ -84,7 +124,6 @@ class CliDB(App):
             ScrollView(self.directory_view), ScrollView(self.database_view), edge="top"
         )
 
-        # TODO: fetch the initial list properly
         await self.database_view.root.add("schemas", "schemas")
         await self.database_view.root.expand()
 
@@ -107,6 +146,7 @@ class CliDB(App):
         await self.results_view.post_message(message)
 
     async def handle_database_views_update(self, message: DatabaseViewsUpdate) -> None:
+        """Handle an updated list of views"""
         await self.database_view.post_message(message)
 
     async def action_query(self) -> None:
@@ -114,6 +154,7 @@ class CliDB(App):
         await self.database.post_message(Query(self, self.query_view.value))
 
     async def handle_file_click(self, message: FileClick) -> None:
+        """Handle a file click event, rendering a loading message pending a reesult"""
         await self.results_view.post_message(
             QueryResult(self, Text("Loading...", justify="center"))
         )
@@ -121,7 +162,12 @@ class CliDB(App):
         await self.database.post_message(OpenFile(self, message.path))
 
 
+def _get_version() -> str:
+    return f"""
+    clidb {__version__} [Python {platform.python_version()}]
+    Copyright 2022 Danny Boland
+    """
+
+
 if __name__ == "__main__":
-    CliDB.run(
-        title="clidb", log="textual.log"
-    )  # pylint: disable=no-value-for-parameter
+    run()
